==> proxy-engine-0.0.2.tgz: package/lib/ProxyLoader.js <==
var Class = require("core").Class;
var Event = require('core').Event.Event;
var ErrorEvent = require('core').Event.ErrorEvent;
var EventDispatcher = require('core').Event.EventDispatcher;
var Loader = require('core').Net.Loader;
var DecoratorChain = require('core').Decorator.DecoratorChain;
var RequestResponseDecorator = require('./decorator/RequestResponseDecorator.js').RequestResponseDecorator;


/**
 * 
 * @class ProxyLoader Managing proxing process
 * @extends EventDispatcher
 * @requires Class 
 * @requires Event 
 * @requires ErrorEvent 
 * @requires EventDispatcher 
 * @requires Loader 
 * @param {Request} request Request object
 * @param {Object} configuration Object holding additional configuration for Decorator's chain creation.</br> 
 *        <i>Example:</i>
 *        <pre>
 *        {
 *            "host" : "example.onet",
 *            "address" : "192.168.1.14",
 *            "port" : "80",
 *            "timeout" : 30000,
 *            "decorators : [
 *                {
 *                    "class": "ExampleDecorator"
 *                    "configuration": {
 *                        "example": "param"
 *                    }     
 *                }
 *            ]  
 *        }
 *        </pre>
 */

var ProxyLoader = function(){
    /** @ignore */
    this.Extends = EventDispatcher;
    
    /**
     * @type {Request} Request Object
     * @private
     * @type {Request}
     */
    this._request = null;

    /**
     * @type {Response} Response Object
     * @private
     * @type {Response}
     */
    this._response = null;

    /**
     * @type {Object} Holds the configuration
     * @private
     */
    this._configuration = null;

    /**
     * 
     * @private
     * @type {DecoratorChain}
     */
    this._decorator = null;

    /** @ignore */
    this.initialize = function(request, configuration){
        this._request = request;
        this._configuration = configuration;
        this._decorator = new DecoratorChain();
    };


    /**
     * Loads specified request which means it will fetch some data
     */
    this.load = function(){
        console.log("ProxyLoader/load");
        if(!this._configuration.hasOwnProperty("host")){
            throw ProxyLoader.Exeption.HOST_NOT_DEFINED;
        }
        //sprawdzamy czy w konfiguracji istnieje wpis address - jesli tak to uzywamy go jako docelowego adresu serwera www
        var host = this._configuration.hasOwnProperty("address") ? this._configuration.address : this._configuration.host;
        this._request.setHost(host);
        //sprawdzamy czy ustawiony został inny port niz domyslny 80.
        if(this._configuration.hasOwnProperty("port")){
            this._request.setPort(this._configuration.port);
        }
        //ustawiamy nagłówek host dla http 1.1
        this._request.setHeader('Host', this._configuration.host);
        //tworzymy chain dekoratorów.
        if(this._configuration.hasOwnProperty("decorators")){
            var count = this._configuration.decorators.length;
            for(var i = 0; i < count; i++){
                //TODO if
                var decoratorClass = this._configuration.decorators[i]["class"];
                
                var decoratorContentType = this._configuration.decorators[i]["contentType"];
                //TODO if
                var decoratorConfig = this._configuration.decorators[i].configuration;
                //tworzenie decoratora
                var decorator = RequestResponseDecorator.create(decoratorClass, decoratorContentType, decoratorConfig);
                this._decorator.addDecorator(decorator);
            }
        }
        console.log("ProxyLoader/load/1");
        this._decorator.addEventListener(DecoratorChain.Event.COMPLETE, this._onRequestDecorationComplete, this);
        this._decorator.addEventListener(DecoratorChain.Event.ERROR_DECORATOR_FAILED, this._onError, this);

        //Odpalamy pierwsza faze dekoracji - dekoracje zadania
        this._decorator.decorate(this._request, 'decorateRequest');
        console.log("ProxyLoader/load/end");
    };
    
    /**
     * Callback for DecoratorChain.Event.COMPLETE after first phase of decoration - decoration of Request object
     * @private
     * @param {Event} e
     */
    this._onRequestDecorationComplete = function(e){
        console.log("ProxyLoader/_onRequestDecorationComplete/begin");
        //Usowamy wywolany listener
        this._decorator.removeEventListener(DecoratorChain.Event.COMPLETE, this._onRequestDecorationComplete, this);
        //Pobieramy zewnetrzną strone
        var loader = new Loader(this._request);
        loader.setFollowRedirects(false);
        loader.addEventListener(Loader.Event.LOADED, this._onSuccess, this);
        loader.addEventListener(Loader.Event.ERROR, this._onError, this);
        loader.load();
        console.log("ProxyLoader/_onRequestDecorationComplete/end");
    };
    
    /**
     * Callback for DecoratorChain.Event.COMPLETE after second phase of decoration - decoration of Response object
     * @private
     * @param {Event} e
     */
    this._onResponseDecorationComplete = function(e){
        console.log("ProxyLoader/_onResponseDecorationComplete/begin");
        this._decorator.removeEventListener(DecoratorChain.Event.COMPLETE, this._onResponseDecorationComplete, this);
        //informujemy o zakonczeniu procesu proxowania
        console.log("ProxyLoader/_onResponseDecorationComplete/end");
        this.dispatchEvent(new Event(ProxyLoader.LOADED, this._response));
    };
    
    /**
     * Callback for Loader.LOADED event, issued when data from loader arrive
     * @private 
     * @param {Event} e
     */
    this._onSuccess = function(e){
        console.log("ProxyLoader/_onSuccess/begin");
        this._response = e.data;
        //TODO obsluga innych kontentów niz text/html
        //Odpalamy druga faze dekoracji - dekoracje odpowiedzi
        this._decorator.addEventListener(DecoratorChain.Event.COMPLETE, this._onResponseDecorationComplete, this);
        console.log("ProxyLoader/_onSuccess/end");
        this._decorator.decorate(this._response, 'dispatchDecorateResponse');
        
    };

    /**
     * Callback for Loader.ERROR event, issued when something goes wrong in Loader
     * @private
     * @param {Event} e
     */
    this._onError = function(e){
        this.dispatchEvent(new ErrorEvent(ProxyLoader.ERROR, e, e.code, e.message));
    };

};

ProxyLoader = new Class( new ProxyLoader() );

/**
 * @static
 * @constant
 */
ProxyLoader.LOADED = "ProxyLoader_LOADED";

/**
 * @static
 * @constant
 */
ProxyLoader.ERROR = "ProxyLoader_ERROR";
/**
 * Namespace for exeptions messages.
 * @static
 * @constant
 * @namespace
 */
ProxyLoader.Exeption = {};
/**
 * @static
 * @constant
 */
ProxyLoader.Exeption.HOST_NOT_DEFINED = "ProxyLoader: Host is not defined in given configuration.";

exports.ProxyLoader = ProxyLoader;

==> proxy-engine-0.0.4.tgz: package/lib/ProxyLoader.js <==
var Class = require("core").Class;
var Event = require('core').Event.Event;
var ErrorEvent = require('core').Event.ErrorEvent;
var EventDispatcher = require('core').Event.EventDispatcher;
var Loader = require('core').Net.Loader;
var DecoratorChain = require('core').Decorator.DecoratorChain;
var RequestResponseDecorator = require('./decorator/RequestResponseDecorator.js').RequestResponseDecorator;


/**
 * 
 * @class ProxyLoader Managing proxing process
 * @extends EventDispatcher
 * @requires Class 
 * @requires Event 
 * @requires ErrorEvent 
 * @requires EventDispatcher 
 * @requires Loader 
 * @param {Request} request Request object
 * @param {Object} configuration Object holding additional configuration for Decorator's chain creation.</br> 
 *        <i>Example:</i>
 *        <pre>
 *        {
 *            "host" : "example.onet",
 *            "address" : "192.168.1.14",
 *            "port" : "80",
 *            "timeout" : 30000,
 *            "decorators : [
 *                {
 *                    "class": "ExampleDecorator"
 *                    "configuration": {
 *                        "example": "param"
 *                    }     
 *                }
 *            ]  
 *        }
 *        </pre>
 */

var ProxyLoader = function(){
    /** @ignore */
    this.Extends = EventDispatcher;
    
    /**
     * @type {Request} Request Object
     * @private
     * @type {Request}
     */
    this._request = null;

    /**
     * @type {Response} Response Object
     * @private
     * @type {Response}
     */
    this._response = null;

    /**
     * @type {Object} Holds the configuration
     * @private
     */
    this._configuration = null;

    /**
     * 
     * @private
     * @type {DecoratorChain}
     */
    this._decorator = null;

    /** @ignore */
    this.initialize = function(request, configuration){
        this._request = request;
        this._configuration = configuration;
        this._decorator = new DecoratorChain();
    };


    /**
     * Loads specified request which means it will fetch some data
     */
    this.load = function(){

        if(!this._configuration.hasOwnProperty("host")){
            throw ProxyLoader.Exeption.HOST_NOT_DEFINED;
        }
        //sprawdzamy czy w konfiguracji istnieje wpis address - jesli tak to uzywamy go jako docelowego adresu serwera www
        var host = this._configuration.hasOwnProperty("address") ? this._configuration.address : this._configuration.host;
        this._request.setHost(host);
        //sprawdzamy czy ustawiony został inny port niz domyslny 80.
        if(this._configuration.hasOwnProperty("port")){
            this._request.setPort(this._configuration.port);
        }
        //ustawiamy nagłówek host dla http 1.1
        this._request.setHeader('Host', this._configuration.host);
        
        
        //tworzymy chain dekoratorów.
        if(this._configuration.hasOwnProperty("decorators")){
            var count = this._configuration.decorators.length;
            for(var i = 0; i < count; i++){
                //TODO if
                var decoratorClass = this._configuration.decorators[i]["class"];
                
                var decoratorContentType = this._configuration.decorators[i]["contentType"];
                //TODO if
                var decoratorConfig = this._configuration.decorators[i].configuration;
                //tworzenie decoratora
                var decorator = RequestResponseDecorator.create(decoratorClass, decoratorContentType, decoratorConfig);
                
                this._decorator.addDecorator(decorator);
            }
        }
        
        this._decorator.addEventListener(DecoratorChain.Event.COMPLETE, this._onRequestDecorationComplete, this);
        this._decorator.addEventListener(DecoratorChain.Event.ERROR_DECORATOR_FAILED, this._onError, this);

        console.log("        -- PL: request decoration started...");
        //Odpalamy pierwsza faze dekoracji - dekoracje zadania
        this._decorator.decorate(this._request, 'decorateRequest');
        
    };
    
    /**
     * Callback for DecoratorChain.Event.COMPLETE after first phase of decoration - decoration of Request object
     * @private
     * @param {Event} e
     */
    this._onRequestDecorationComplete = function(e){
        console.log("        -- PL: request decoration completed");
        //Usuwamy wywolany listener
        this._decorator.removeEventListener(DecoratorChain.Event.COMPLETE, this._onRequestDecorationComplete, this);
        
        console.log("        -- PL: downloading remote file/page...");
        //Pobieramy zewnetrzną strone
        var loader = new Loader(this._request);
        if(this._configuration.hasOwnProperty("timeout")){
            loader.setTimeout(this._configuration.timeout);
        }
        loader.setFollowRedirects(false);
        loader.addEventListener(Loader.Event.LOADED, this._onSuccess, this);
        loader.addEventListener(Loader.Event.ERROR, this._onError, this);
        console.time('        -- PL: Loader return results after');
        loader.load();
    };
    
    /**
     * Callback for DecoratorChain.Event.COMPLETE after second phase of decoration - decoration of Response object
     * @private
     * @param {Event} e
     */
    this._onResponseDecorationComplete = function(e){
        console.log("        -- PL: response decoration completed");
        this._decorator.removeEventListener(DecoratorChain.Event.COMPLETE, this._onResponseDecorationComplete, this);
        //informujemy o zakonczeniu procesu proxowania
        console.log("        -- PL: work done. dispatching LOADED...");
        this.dispatchEvent(new Event(ProxyLoader.LOADED, this._response));
    };
    
    /**
     * Callback for Loader.LOADED event, issued when data from loader arrive
     * @private 
     * @param {Event} e
     */
    this._onSuccess = function(e){
        console.timeEnd('        -- PL: Loader return results after');
        console.log("        -- PL: downloaded!");
        this._response = e.data;
        //TODO obsluga innych kontentów niz text/html
        //Odpalamy druga faze dekoracji - dekoracje odpowiedzi
        this._decorator.addEventListener(DecoratorChain.Event.COMPLETE, this._onResponseDecorationComplete, this);
        console.log("        -- PL: response decoration started...");
        this._decorator.decorate(this._response, 'dispatchDecorateResponse');
    };

    /**
     * Callback for Loader.ERROR event, issued when something goes wrong in Loader
     * @private
     * @param {Event} e
     */
    this._onError = function(e){
        console.timeEnd('        -- PL: Loader return results after');
        console.log("        -- PL: Loader ERROR occured!");
        this.dispatchEvent(new ErrorEvent(ProxyLoader.ERROR, e, e.code, e.message));
    };

};

ProxyLoader = new Class( new ProxyLoader() );

/**
 * @static
 * @constant
 */
ProxyLoader.LOADED = "ProxyLoader_LOADED";

/**
 * @static
 * @constant
 */
ProxyLoader.ERROR = "ProxyLoader_ERROR";
/**
 * Namespace for exeptions messages.
 * @static
 * @constant
 * @namespace
 */
ProxyLoader.Exeption = {};
/**
 * @static
 * @constant
 */
ProxyLoader.Exeption.HOST_NOT_DEFINED = "ProxyLoader: Host is not defined in given configuration.";

exports.ProxyLoader = ProxyLoader;
